@@ -25,6 +25,7 @@ namespace PodSleuth
         private List<ImageFormat> image_formats = new List<ImageFormat>();
         private bool photos_supported = false;
         private bool album_art_supported = false;
+        private bool sparse_album_art_supported = false;
         private bool chapter_images_supported = false;
         private bool is_shuffle = false;
         
@@ -157,6 +158,10 @@ namespace PodSleuth
             if(ReadPlistBool("vCardsSupported")) {
                 capabilities |= DeviceCapabilities.VCard;
             }
+
+            if(ReadPlistBool("SupportsSparseArtwork")) {
+                sparse_album_art_supported = true;
+            }
             
             if(plist_dict.ContainsKey("VisibleBuildID")) {
                 firmware_version = ((PlistString)plist_dict["VisibleBuildID"]).Value;
@@ -325,6 +330,10 @@ namespace PodSleuth
         public bool AlbumArtSupported {
             get { return album_art_supported; }
         }
+
+        public bool SparseAlbumArtSupported {
+            get { return sparse_album_art_supported; }
+        }
         
         public bool ChapterImagesSupported {
             get { return chapter_images_supported; }
